import IBindableArray from './IBindableArray';
/**
 * Determines index of the first item the `isHigher` callback returns true for. If such an item does not exist,
 * returns the array length. The input array must be ordered in such a way that all values such that
 * `!isHigher(value)` go before `isHigher(value)`.
 * @param arr Sorted array.
 * @param isHigher Should return true if the argument is "higher" than the searched value.
 * @returns Array index.
 */
export declare function binarySearch<T>(arr: readonly T[], isHigher: (value: T) => boolean): number;
/**
 * Iterates through array items in backward order.
 * @param arr Array.
 * @param callback Callback.
 */
export declare function backForEach<T>(arr: readonly T[], callback: (item: T, index: number) => void): void;
/**
 * @param arr Array.
 * @returns Every item in `arr` is equal to its index: `arr[i] === i`.
 */
export declare function isIdentity(arr: readonly number[]): boolean;
/**
 * Builds a new array by the rule: `result[arr[i]] === i` and returns it.
 *
 * @param arr Array to invert.
 * @returns New inverted array.
 */
export declare function invert(arr: readonly number[]): number[];
/**
 * Builds a new array consisting of subarray items in the same order.
 *
 * @param arrays Array of subarrays.
 * @returns Merged array.
 */
export declare function merge<T>(arrays: readonly (readonly T[])[]): T[];
/**
 * Adds a range of new items to an array.
 * @param arr Array to modify.
 * @param items Items to add.
 * @param index Index of an item to add the new ones before. By default, appends the items to the end of array.
 */
export declare function addAll<T>(arr: T[], items: Iterable<T>, index?: number): void;
/**
 * Moves an item in an array.
 * @param arr Array to modify.
 * @param fromIndex Index of an item to move.
 * @param toIndex Index to move the item to.
 * @returns Value of the moved item.
 */
export declare function move<T>(arr: T[], fromIndex: number, toIndex: number): T;
/**
 * Removes and inserts item ranges.
 * @param arr Array to modify.
 * @param segmentsToRemove Array of segments to remove sorted by index asc. Segments are removed in backward order.
 * @param segmentsToAdd Array of segments to insert sorted by index asc. Segments are inserted in forward order.
 * @returns Splice result. If the array is not modified, returns undefined.
 */
export declare function trySplice<T>(arr: T[], segmentsToRemove: Iterable<IBindableArray.IndexCount>, segmentsToAdd: Iterable<IBindableArray.IndexItems<T>>): IBindableArray.SpliceResult<T>;
/**
 * Reorders array items.
 * @param arr Array to modify.
 * @param indexArray Index array. Item with index `i` will be moved to index `indexArray[i]`.
 * Must contain all indexes from 0 to (length - 1).
 * @returns Old array contents. If the array is not modified, returns undefined.
 */
export declare function tryReorder<T>(arr: T[], indexArray: readonly number[]): T[];
