import DestroyableBindable from "./DestroyableBindable";
import Listenable from "./Listenable";
import Mapper from "./Mapper";
/**
 * Read-only container for a value.
 * Provides basic data binding functionality.
 */
interface Bindable<V> {
    /**
     * Property value has just been changed. Dispatched in result of `set` method call if the value has been changed.
     */
    readonly silent: boolean;
    /**
     * Property value is changed. Triggered in result of `set` method call if the value has been changed.
     */
    readonly onChange: Listenable<Bindable.ChangeMessage<V>>;
    /**
     * Think twice before calling this method - probably it makes sense to use some kind of binding instead?
     * @returns Current property value.
     */
    get(): V;
    /**
     * Creates a new property bound to this property, keeping it equal to the result of a function call for value
     * of this property.
     *
     * @param create Mapping function.
     * @param config Configuration options.
     */
    map<U>(create: (value: V) => U, config?: Mapper.Config<U>): DestroyableBindable<U>;
}
export default Bindable;
declare namespace Bindable {
    /**
     * `Bindable` change message.
     */
    interface ChangeMessage<V> {
        /**
         * Property that has its value changed.
         */
        readonly sender: Bindable<V>;
        /**
         * New property value.
         */
        readonly value: V;
        /**
         * Old property value.
         */
        readonly oldValue: V;
    }
}
