import Bindable from './Bindable';
import Class from './Class';
import IBindableArray from './IBindableArray';
import Listenable from './Listenable';
/**
 * Implementation of a bindable wrapper over a native array.
 */
export default class BindableArray<T> extends Class implements IBindableArray<T> {
    private _ownsValues;
    private readonly _length;
    private readonly _native;
    private readonly _onSplice;
    private readonly _onReplace;
    private readonly _onMove;
    private readonly _onReorder;
    private readonly _onClear;
    private readonly _onChange;
    /**
     * @param silent Create a silent array which means that it never dispatches any messages.
     */
    constructor(silent?: boolean);
    /**
     * @param contents Initial array contents.
     * @param silent Create a silent array which means that it never dispatches any messages.
     */
    constructor(contents: Iterable<T>, silent?: boolean);
    protected destroyObject(): void;
    [Symbol.iterator](): IterableIterator<T>;
    get silent(): boolean;
    get length(): Bindable<number>;
    get native(): readonly T[];
    get onSplice(): Listenable<IBindableArray.SpliceResult<T>>;
    get onReplace(): Listenable<IBindableArray.ReplaceMessage<T>>;
    get onMove(): Listenable<IBindableArray.MoveMessage<T>>;
    get onReorder(): Listenable<IBindableArray.ReorderMessage<T>>;
    get onClear(): Listenable<readonly T[]>;
    get onChange(): Listenable<void>;
    ownValues(): this;
    get(index: number): T;
    includes(value: T): boolean;
    indexOf(value: T): number;
    lastIndexOf(value: T): number;
    every(callback: (value: T, index: number) => boolean): boolean;
    some(callback: (value: T, index: number) => boolean): boolean;
    forEach(callback: (value: T, index: number) => void): void;
    find(callback: (value: T, index: number) => boolean): T;
    findIndex(callback: (value: T, index: number) => boolean): number;
    reduce<U>(callback: (accumulator: U, value: T, index: number) => U, initial: U): U;
    reduceRight<U>(callback: (accumulator: U, value: T, index: number) => U, initial: U): U;
    add(value: T, index?: number): void;
    addAll(values: readonly T[], index?: number): void;
    set(index: number, newValue: T): T;
    trySet(index: number, newValue: T): T;
    remove(index: number): T;
    removeAll(index: number, count: number): T[];
    tryRemoveAll(index: number, count: number): T[];
    removeValues(values: Iterable<T>): void;
    move(fromIndex: number, toIndex: number): T;
    tryMove(fromIndex: number, toIndex: number): T;
    clear(): T[];
    splice(segmentsToRemove: Iterable<IBindableArray.IndexCount>, segmentsToAdd: Iterable<IBindableArray.IndexItems<T>>): IBindableArray.SpliceResult<T>;
    trySplice(segmentsToRemove: Iterable<IBindableArray.IndexCount>, segmentsToAdd: Iterable<IBindableArray.IndexItems<T>>): IBindableArray.SpliceResult<T>;
    reorder(indexMapping: readonly number[]): void;
    tryReorder(indexMapping: readonly number[]): T[];
    detectSplice(newContents: readonly T[]): IBindableArray.SpliceParams<T>;
    detectFilter(newContents: readonly T[]): IBindableArray.IndexCount[];
    detectReorder(newContents: readonly T[]): number[];
    detectSort(callback?: (value: T, index: number) => any, order?: number): number[];
    detectSortComparing(compare?: (t1: T, t2: T, i1: number, i2: number) => number, order?: number): number[];
    performSplice(newContents: readonly T[]): void;
    performFilter(newContents: readonly T[]): void;
    performReorder(newContents: readonly T[]): void;
    sort(callback?: (value: T, index: number) => any, order?: number): void;
    sortComparing(compare?: (t1: T, t2: T, i1: number, i2: number) => number, order?: number): void;
    reverse(): void;
}
