import Bindable from './Bindable';
import Class from './Class';
import IBindableMap from './IBindableMap';
import Listenable from './Listenable';
import Some from './Some';
/**
 * Implementation of a bindable wrapper over a native map.
 */
declare class BindableMap<K, V> extends Class implements IBindableMap<K, V> {
    private _ownsValues;
    private _size;
    private _native;
    private _onSplice;
    private _onReindex;
    private _onClear;
    private _onChange;
    /**
     * @param silent Create a silent map which means that it never dispatches any messages.
     */
    constructor(silent?: boolean);
    /**
     * @param contents Initial map contents.
     * @param silent Create a silent map which means that it never dispatches any messages.
     */
    constructor(contents: Iterable<readonly [K, V]>, silent?: boolean);
    protected destroyObject(): void;
    [Symbol.iterator](): IterableIterator<[K, V]>;
    get silent(): boolean;
    get size(): Bindable<number>;
    get native(): ReadonlyMap<K, V>;
    get onSplice(): Listenable<IBindableMap.SpliceResult<K, V>>;
    get onReindex(): Listenable<ReadonlyMap<K, K>>;
    get onClear(): Listenable<ReadonlyMap<K, V>>;
    get onChange(): Listenable<void>;
    ownValues(): this;
    has(key: K): boolean;
    get(key: K): V;
    keys(): IterableIterator<K>;
    values(): IterableIterator<V>;
    entries(): IterableIterator<readonly [K, V]>;
    forEach(callback: (value: V, key: K) => void): void;
    set(key: K, value: V): V;
    trySet(key: K, value: V): Some<V>;
    setAll(entries: ReadonlyMap<K, V>): void;
    trySetAll(entries: ReadonlyMap<K, V>): IBindableMap.SpliceResult<K, V>;
    setKey(oldKey: K, newKey: K): V;
    trySetKey(oldKey: K, newKey: K): V;
    delete(key: K): V;
    deleteAll(keys: Iterable<K>): void;
    tryDeleteAll(keys: Iterable<K>): Map<K, V>;
    clear(): Map<K, V>;
    tryClear(): Map<K, V>;
    splice(keysToDelete: Iterable<K>, entriesToUpdate: ReadonlyMap<K, V>): IBindableMap.SpliceResult<K, V>;
    trySplice(keysToDelete: Iterable<K>, entriesToUpdate: ReadonlyMap<K, V>): IBindableMap.SpliceResult<K, V>;
    reindex(keyMapping: ReadonlyMap<K, K>): Map<K, K>;
    tryReindex(keyMapping: ReadonlyMap<K, K>): Map<K, K>;
    detectSplice(newContents: ReadonlyMap<K, V>): IBindableMap.SpliceParams<K, V>;
    detectReindex(newContents: ReadonlyMap<K, V>): ReadonlyMap<K, K>;
    performSplice(newContents: ReadonlyMap<K, V>): void;
    performReindex(newContents: ReadonlyMap<K, V>): void;
}
export default BindableMap;
