import Bindable from './Bindable';
import Class from './Class';
import IBindableSet from './IBindableSet';
import Listenable from './Listenable';
/**
 * Implementation of a bindable wrapper over a native set.
 */
declare class BindableSet<T> extends Class implements IBindableSet<T> {
    private _ownsValues;
    private _size;
    private _native;
    private _onSplice;
    private _onClear;
    private _onChange;
    /**
     * @param silent Create a silent set which means that it never dispatches any messages.
     */
    constructor(silent?: boolean);
    /**
     * @param contents Initial set contents.
     * @param silent Create a silent set which means that it never dispatches any messages.
     */
    constructor(contents: Iterable<T>, silent?: boolean);
    protected destroyObject(): void;
    [Symbol.iterator](): IterableIterator<T>;
    get silent(): boolean;
    get size(): Bindable<number>;
    get native(): ReadonlySet<T>;
    get onSplice(): Listenable<IBindableSet.SpliceResult<T>>;
    get onClear(): Listenable<ReadonlySet<T>>;
    get onChange(): Listenable<void>;
    ownValues(): this;
    has(value: T): boolean;
    forEach(callback: (value: T) => void): void;
    add(value: T): boolean;
    addAll(values: Iterable<T>): ReadonlySet<T>;
    tryAddAll(values: Iterable<T>): ReadonlySet<T>;
    delete(value: T): boolean;
    deleteAll(values: Iterable<T>): ReadonlySet<T>;
    tryDeleteAll(values: Iterable<T>): ReadonlySet<T>;
    clear(): ReadonlySet<T>;
    tryClear(): ReadonlySet<T>;
    splice(valuesToDelete: Iterable<T>, valuesToAdd: Iterable<T>): IBindableSet.SpliceResult<T>;
    trySplice(valuesToDelete: Iterable<T>, valuesToAdd: Iterable<T>): IBindableSet.SpliceResult<T>;
    detectSplice(newContents: Iterable<T>): IBindableSet.SpliceParams<T>;
    performSplice(newContents: Iterable<T>): void;
}
export default BindableSet;
