/**
 * Checks if value is a jQuery element.
 */
export declare function isElement(value: any): boolean;
/**
 * Checks if the element is a text input.
 *
 * @param el Element.
 * @returns Element is a text input.
 */
export declare function isTextInput(el: InputElement): boolean;
export interface InputElement {
    prop(prop: "tagName"): string;
    attr(attr: "type"): string;
}
/**
 * Checks if current HTML document body contains the specified element.
 *
 * @param el HTML element.
 * @returns Element is in DOM.
 */
export declare function inDom(el: HTMLElement): boolean;
/**
 * Checks deeply if one HTML element is a descendant of another element.
 *
 * @param descendantEl Descendant HTML element to check.
 * @param ancestorEl Ancestor HTML element to check.
 * @returns Element is a descendant of another element.
 */
export declare function inEl(descendantEl: HTMLElement, ancestorEl: HTMLElement): boolean;
/**
 * Checks if element contains the specified CSS class name.
 *
 * @param el HTML element.
 * @param cls Single CSS class name.
 * @return Element contains this CSS class name.
 */
export declare function hasClass(el: HTMLElement, cls: string): boolean;
/**
 * Adds the specified CSS class name to element unless it already contains it.
 *
 * @param el HTML element.
 * @param cls Single CSS class name.
 */
export declare function addClass(el: HTMLElement, cls: string): void;
/**
 * Parses HTML and builds a new DOM element.
 *
 * @param html HTML code to parse.
 * @returns New HTML element.
 */
export declare function parseHtml(html: string): HTMLElement;
/**
 * Inserts element as a child at specified position.
 *
 * @param parent Element to insert into.
 * @param child Element to insert.
 * @param index Position to insert at.
 */
export declare function insert(parent: Node, child: Node, index?: number): void;
/**
 * Removes element from DOM.
 *
 * @param el Element to remove.
 */
export declare function remove(el: Node): void;
/**
 * Replaces one HTML element with another.
 *
 * @param removeEl Element to replace.
 * @param insertEl Element to replace `removeEl` with.
 * @param attrs If true, retains element `id` and `class`
 */
export declare function replace(removeEl: HTMLElement, insertEl: HTMLElement, attrs?: boolean): void;
export declare function _afterAppend(child: {
    _afterAppend: () => void;
}): void;
