import Destroyable from './Destroyable';
/**
 * Introduces object aggregation support.
 * If you call `a.own(b)`, then **b** is destroyed automatically on **a** destruction.
 * You can aggregate any object implementing Destroyable.
 *
 * See online documentation for details.
 */
interface IClass extends Destroyable {
    /**
     * Aggregates the object. It means that the specified object is automatically destroyed
     * on this object destruction. The aggregated objects are destroyed in reverse order.
     * Returns the aggregated object, which makes it easy to use in field definition.
     *
     * @param obj Object to aggregate.
     */
    own<T extends Destroyable>(obj: T): T;
    /**
     * Aggregates the object. It means that the specified object is automatically destroyed
     * on this object destruction. The aggregated objects are destroyed in reverse order.
     * Returns this object, which makes it easy to use in object instantiation.
     *
     * @param obj Object to aggregate.
     */
    owning(obj: Destroyable): this;
}
export default IClass;
