import DestroyableBindable from "./DestroyableBindable";
import IClass from "./IClass";
/**
 * Extension of `DestroyableBindable` interface with `set` method to modify the property value.
 */
interface IProperty<V> extends IClass, DestroyableBindable<V> {
    /**
     * Changes the property value and dispatches a change message if the value has truly been changed.
     */
    set(value: V): void;
    /**
     * Makes this property an owner of its value. It means that the value is
     * destroyed automatically on reassignment or destruction of the property.
     */
    ownValue(): this;
}
export default IProperty;
