/**
 * Maps iterable items. Returns an array containing results of a callback call for each iterable item.
 * @param iterable Iterable.
 * @param callback Mapping function.
 * @returns Mapped array.
 */
export declare function map<T, U>(iterable: Iterable<T>, callback: (item: T) => U): U[];
/**
 * Filters an iterable by criteria. Builds an array consisting of items a callback returns true for.
 * @param iterable Iterable.
 * @param callback Criteria callback.
 * @returns Filtered array.
 */
export declare function filter<T>(iterable: Iterable<T>, callback: (item: T) => boolean): T[];
/**
 * Counts items matching a criteria. Returns number of items which `callback` returns true for.
 * @param iterable Iterable.
 * @param callback Criteria callback.
 * @returns Number of items.
 */
export declare function count<T>(iterable: Iterable<T>, callback: (item: T) => boolean): number;
/**
 * Indexes an iterable. Builds and returns a new map by rule: key is the result of the indexer function call,
 * value is the corresponding item.
 * @param iterable Iterable.
 * @param callback Indexer function.
 * @returns Index.
 */
export declare function index<V, K>(iterable: Iterable<V>, callback: (item: V) => K): Map<K, V>;
