import Destroyable from "./Destroyable";
/**
 * Container for handler functions. Provides basic message dispatching functionality.
 */
interface Listenable<M> {
    /**
     * Checks if this dispatcher is dummy, i.e. it never dispatches any messages.
     * This knowledge may help you do certain code optimizations.
     */
    readonly dummy: boolean;
    /**
     * Registers a listener for this dispatcher.
     *
     * Whenever a message is dispatched with `dispatch` method, the specified handler function is called.
     *
     * You can unregister the listener destroying the returned object.
     *
     * @param handler Handler function.
     * @param scope `handler` call scope.
     */
    listen(handler: (message: M) => any, scope?: any): Destroyable;
}
export default Listenable;
