import Bindable from './Bindable';
import Class from './Class';
/**
 * Listens source property modification and calls the specified functions.
 */
declare class Switcher<T> extends Class {
    readonly source: Bindable<T>;
    private _init;
    private _done;
    private _scope;
    private _acceptNil;
    private _value;
    /**
     * @param source Source property.
     * @param config Configuration.
     */
    constructor(source: Bindable<T>, config?: Switcher.Config<T>);
    protected destroyObject(): void;
    private _update;
    private _doInit;
    private _doDone;
}
declare namespace Switcher {
    /**
     * Switcher callback.
     */
    interface Callback<T> {
        (value: T): any;
    }
    /**
     * Configuration of Switcher.
     */
    interface Config<T> {
        /**
         * Value initialization callback.
         */
        readonly init?: Callback<T>;
        /**
         * Value releasing callback.
         */
        readonly done?: Callback<T>;
        /**
         * `init` and `done` call scope. Defaults to switcher itself.
         */
        readonly scope?: any;
        /**
         * Set to true if you want the callbacks to be called even if one of source values is null.
         */
        readonly acceptNil?: boolean;
    }
}
export default Switcher;
