import Bindable from './Bindable';
import Destroyable from './Destroyable';
/**
 * Binds presence of a CSS class of a DOM element to a boolean `Property`.
 * @param el DOM element.
 * @param cls CSS class name.
 * @param property Property to bind presence of the CSS class to.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindClass(el: ClassUpdaterElement, cls: string, property: Bindable<boolean>): Destroyable;
/**
 * Binds name of a CSS class of a DOM element to a string `Property`.
 * @param el DOM element.
 * @param cls Property containing a CSS class name.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindClass(el: ClassNameUpdaterElement, cls: Bindable<string>): Destroyable;
export interface ClassUpdaterElement {
    toggleClass(cls: string, value: boolean): void;
}
export interface ClassNameUpdaterElement {
    addClass(cls: string): void;
    removeClass(cls: string): void;
}
