import Bindable from './Bindable';
import Destroyable from './Destroyable';
import DestroyableBindable from './DestroyableBindable';
import IProperty from './IProperty';
/**
 * Returns a new boolean `Property` bound to checkbox state of a DOM element.
 * Only "checked" JQuery property is supported in this case.
 * @param el DOM element.
 * @param prop JQuery property name.
 * @returns Bound `Property`. You must destroy it to stop the synchronization.
 */
export default function bindProp(el: CheckedWatcherElement, prop: "checked"): DestroyableBindable<boolean>;
/**
 * Binds a JQuery property of a DOM element to a boolean `Property`.
 * @param el DOM element.
 * @param prop JQuery property name.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindProp(el: PropUpdaterElement, prop: string, property: Bindable<boolean>, binding?: 1): Destroyable;
/**
 * Binds a boolean `Property` to a JQuery property of a DOM element.
 * Only "checked" JQuery property is supported in this case.
 * @param el DOM element.
 * @param prop JQuery property name.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Bound property. You must destroy it to stop the synchronization.
 */
export default function bindProp(el: CheckedWatcherElement, prop: "checked", property: IProperty<boolean>, binding: 2): Destroyable;
/**
 * Sets up a two-way binding between a JQuery property of a DOM element and a boolean `Property`.
 * Initially, the boolean property value prevails.
 * Only "checked" JQuery property is supported in this case.
 * @param el DOM element.
 * @param prop JQuery property name.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindProp(el: PropUpdaterElement & CheckedWatcherElement, prop: "checked", property: IProperty<boolean>, binding: 3): Destroyable;
export interface PropUpdaterElement {
    prop(prop: string, value: boolean): void;
    change(): void;
}
export interface CheckedWatcherElement {
    prop(prop: "checked"): boolean;
    on(event: "change", callback: () => void): void;
    off(event: "change", callback: () => void): void;
}
