import Bindable from './Bindable';
import Destroyable from './Destroyable';
import DestroyableBindable from './DestroyableBindable';
import IProperty from './IProperty';
/**
 * Returns a new string `Property` bound to radio button selection in a DOM element.
 * @param el DOM element.
 * @param name Value of "name" attribute in radio button elements.
 * @returns Bound property. You must destroy it to stop the synchronization.
 */
export default function bindRadio(el: RadioWatcherField, name: string): DestroyableBindable<string>;
/**
 * Binds radio button selection in a DOM element to a string `Property`.
 * @param el DOM element.
 * @param name Value of "name" attribute in radio button elements.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindRadio(el: RadioUpdaterField, name: string, property: Bindable<string>, binding?: 1): Destroyable;
/**
 * Binds a string `Property` to radio button selection in a DOM element.
 * @param el DOM element.
 * @param name Value of "name" attribute in radio button elements.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindRadio(el: RadioWatcherField, name: string, property: IProperty<string>, binding: 2): Destroyable;
/**
 * Sets up a two-way binding between radio button selection in a DOM element and a string `Property`.
 * Initially, the property value prevails.
 * @param el DOM element.
 * @param name Value of "name" attribute in radio button elements.
 * @param property Property.
 * @param binding Binding direction.
 */
export default function bindRadio(el: RadioField, name: string, property: IProperty<string>, binding: 3): Destroyable;
export interface RadioUpdaterField {
    find(selector: string): RadioUpdaterButton;
}
export interface RadioUpdaterButton {
    readonly length: number;
    is(selector: ":checked"): boolean;
    prop(prop: "checked", value: boolean): void;
    change(): void;
}
export interface RadioWatcherField {
    find(selector: string): RadioWatcherButton;
    on(event: "change", selector: string, callback: () => void): void;
    off(event: "change", selector: string, callback: () => void): void;
}
export interface RadioWatcherButton {
    readonly length: number;
    attr(attr: "value"): string;
}
export interface RadioField extends RadioUpdaterField, RadioWatcherField {
    find(selector: string): RadioUpdaterButton & RadioWatcherButton;
}
