import Bindable from './Bindable';
import Destroyable from './Destroyable';
import DestroyableBindable from './DestroyableBindable';
import { InputElement } from './DomUtils';
import IProperty from './IProperty';
/**
 * Returns a new `Property` bound to value of a DOM element.
 * @param el DOM element.
 * @param simple Disable live watch by timer.
 * @returns Bound property. You must destroy it to stop the synchronization.
 */
export default function bindVal<T extends string | number | string[]>(el: ValueWatcherElement, simple?: boolean): DestroyableBindable<T>;
/**
 * Binds value of a DOM element to a `Property`.
 * @param el DOM element.
 * @param property Property.
 * @param binding Binding direction.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindVal<T extends string | number | string[]>(el: ValueUpdaterElement<T>, property: Bindable<T>, binding?: 1): Destroyable;
/**
 * Binds a `Property` to value of a DOM element.
 * @param el DOM element.
 * @param property Property.
 * @param binding Binding direction.
 * @param simple Disable live watch by timer.
 * @returns Binding object. You must destroy it to stop the synchronization.
 */
export default function bindVal<T extends string | number | string[]>(el: ValueWatcherElement, property: IProperty<T>, binding: 2, simple?: boolean): Destroyable;
/**
 * Sets up a two-way binding between value of a DOM element and a `Property`.
 * Initially, the property value prevails.
 * @param el DOM element.
 * @param property Property.
 * @param binding Binding direction.
 * @param simple Disable live watch by timer.
 */
export default function bindVal<T extends string | number | string[]>(el: ValueUpdaterElement<T> & ValueWatcherElement, property: IProperty<T>, binding: 3, simple?: boolean): Destroyable;
export interface ValueUpdaterElement<T extends string | number | string[]> {
    val(): string | number | string[];
    val(value: T): void;
    change(): void;
}
export interface ValueWatcherElement extends InputElement {
    val(): string | number | string[];
    on(event: "change", callback: () => void): void;
    off(event: "change", callback: () => void): void;
}
