import Class from '../Class';
/**
 * Binds one collection to another, filling it with results of a function call for each value of the source collection.
 */
declare abstract class AbstractMapper<T, U> extends Class {
    protected _create: (data: T) => U;
    protected _destroy: (item: U, data: T) => void;
    protected constructor(_create: (data: T) => U, config?: AbstractMapper.Config<T, U>);
    protected destroyObject(): void;
}
export default AbstractMapper;
declare namespace AbstractMapper {
    /**
     * Signature of `AbstractMapper.Config.destroy` callback.
     */
    interface DestroyCallback<T, U> {
        (targetValue: U, sourceValue: T): void;
    }
    /**
     * Configuration of `AbstractMapper`.
     */
    interface Config<T, U> {
        /**
         * Destructor of a mapped value. Destroys a value when it leaves the target collection.
         */
        readonly destroy?: DestroyCallback<T, U>;
    }
}
