import Class from "../Class";
import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from '../IBindableArray';
import ReadonlyBindableArray from '../ReadonlyBindableArray';
/**
 * Binds one array to another, filling it with items of the source array a function returns a truthy value for in the
 * same order.
 */
declare class ArrayFilterer<T> extends Class {
    readonly source: ReadonlyBindableArray<T>;
    private test;
    private _target;
    private _targetCreated;
    private _filtered;
    /**
     * @param source Source array.
     * @param test Filtering criteria.
     * @param config Filterer configuration.
     */
    constructor(source: ReadonlyBindableArray<T>, test: (value: T) => boolean, config?: ArrayFilterer.Config<T>);
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<T>;
    /**
     * Changes filterer configuration and refilters the target array.
     * @param config Options to modify.
     */
    reconfigure(config: ArrayFilterer.Reconfig<T>): void;
    /**
     * Refilters an item at specified position in the source array.
     * Call this method when the item properties change in such a way that it must be refiltered.
     */
    refilterAt(sourceIndex: number): void;
    /**
     * Refilters the target array. Call this method when properties of arbitrary array items change in such a way
     * that they must be refiltered.
     */
    refilter(): void;
    protected destroyObject(): void;
    private _countFiltered;
    private _splice;
    private _onSplice;
    private _onReplace;
    private _onMove;
    private _onClear;
    private _onReorder;
}
export default ArrayFilterer;
declare namespace ArrayFilterer {
    /**
     * Configuration of `ArrayFilterer`.
     */
    interface Config<T> {
        /**
         * Target array.
         */
        readonly target?: IBindableArray<T>;
    }
    /**
     * Configuration of `ArrayFilterer.reconfigure` method.
     * All options are optional. If skipped, an option stays the same.
     */
    interface Reconfig<T> {
        /**
         * New filtering criteria.
         */
        readonly test?: (value: T) => boolean;
    }
}
/**
 * Creates a new array bound to another array with `ArrayFilterer`.
 * @param source Source array.
 * @param test Filtering criteria.
 * @returns Target array.
 */
export declare function startFilteringArray<T>(source: ReadonlyBindableArray<T>, test: (value: T) => boolean): DestroyableReadonlyBindableArray<T>;
