import Class from '../Class';
import ReadonlyBindableArray from '../ReadonlyBindableArray';
/**
 * Handles all messages of `ReadonlyBindableArray` with a combination of three callbacks.
 */
declare class ArrayInserter<T> extends Class {
    readonly source: ReadonlyBindableArray<T>;
    protected _add: (item: T, index: number) => void;
    protected _remove: (item: T, index: number) => void;
    protected _clear: (items: readonly T[]) => void;
    /**
     * @param source Source array.
     * @param config Inserter configuration.
     */
    constructor(source: ReadonlyBindableArray<T>, config?: ArrayInserter.Config<T>);
    protected destroyObject(): void;
    private _addItems;
    private _removeItems;
    private _doClearItems;
    private _onSplice;
    private _onReplace;
    private _onMove;
    private _onClear;
    private _onReorder;
}
export default ArrayInserter;
declare namespace ArrayInserter {
    /**
     * Configuration of `ArrayInserter`.
     */
    interface Config<T> {
        /**
         * Callback to call when an item is added to the array or moved in the array.
         */
        readonly add?: (item: T, index: number) => void;
        /**
         * Callback to call when an item is removed from the array or moved in the array.
         */
        readonly remove?: (item: T, index: number) => void;
        /**
         * Callback to call when the array is cleared. By default, calls `remove` for all array items.
         */
        readonly clear?: (items: readonly T[]) => void;
    }
}
