import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from '../IBindableArray';
import ReadonlyBindableArray from '../ReadonlyBindableArray';
import AbstractMapper from './AbstractMapper';
/**
 * `AbstractMapper` implementation for arrays.
 */
declare class ArrayMapper<T, U> extends AbstractMapper<T, U> {
    readonly source: ReadonlyBindableArray<T>;
    private _target;
    private _targetCreated;
    /**
     * @param source Source array.
     * @param create Mapping callback.
     * @param config Mapper configuration.
     */
    constructor(source: ReadonlyBindableArray<T>, create: (sourceValue: T) => U, config?: ArrayMapper.FullConfig<T, U>);
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<U>;
    protected destroyObject(): void;
    private _createItems;
    private _destroyItems;
    private _onSplice;
    private _onReplace;
    private _onMove;
    private _onClear;
    private _onReorder;
}
export default ArrayMapper;
declare namespace ArrayMapper {
    /**
     * Configuration of `ArrayMapper`.
     */
    interface FullConfig<T, U> extends AbstractMapper.Config<T, U> {
        /**
         * Target array.
         */
        readonly target?: IBindableArray<U>;
    }
}
/**
 * Creates a new array bound to another array with `ArrayMapper`.
 * @param source Source array.
 * @param create Mapping callback.
 * @param config Mapper configuration.
 * @returns Target array.
 */
export declare function startMappingArray<T, U>(source: ReadonlyBindableArray<T>, create: (sourceValue: T) => U, config?: AbstractMapper.Config<T, U>): DestroyableReadonlyBindableArray<U>;
