import Class from '../Class';
import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from '../IBindableArray';
import ReadonlyBindableArray from '../ReadonlyBindableArray';
/**
 * Binds one array to another array of subarrays, filling it with items of the subarrays in the same order.
 */
declare class ArrayMerger<T> extends Class {
    readonly source: ReadonlyBindableArray<ReadonlyBindableArray<T>>;
    private _targetCreated;
    private _bunches;
    private _target;
    /**
     * @param source Source arrays.
     * @param config Merger configuration.
     */
    constructor(source: ReadonlyBindableArray<ReadonlyBindableArray<T>>, config?: ArrayMerger.Config<T>);
    protected destroyObject(): void;
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<T>;
    private _createTarget;
    private _getAllItems;
    private _merge;
    private _count;
    private _getIndexes;
    private _onSplice;
    private _onReplace;
    private _onMove;
    private _onClear;
    private _onReorder;
}
export default ArrayMerger;
declare namespace ArrayMerger {
    /**
     * Configuration of `ArrayMerger`.
     */
    interface Config<T> {
        /**
         * Target array. By default, created automatically.
         */
        readonly target?: IBindableArray<T>;
    }
}
/**
 * Creates a new array bound to another array with `ArrayMerger`.
 * @param source Source array.
 * @returns Merged array.
 */
export declare function startMergingArrays<T>(source: ReadonlyBindableArray<ReadonlyBindableArray<T>>): DestroyableReadonlyBindableArray<T>;
