import Class from '../Class';
import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from '../IBindableArray';
import ReadonlyBindableArray from '../ReadonlyBindableArray';
/**
 * Binds one array to another, filling it with items of the source array in reverse order.
 */
declare class ArrayReverser<T> extends Class {
    readonly source: ReadonlyBindableArray<T>;
    private _targetCreated;
    private _target;
    /**
     * @param source Source array.
     * @param config Reverser configuration.
     */
    constructor(source: ReadonlyBindableArray<T>, config?: ArrayReverser.Config<T>);
    protected destroyObject(): void;
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<T>;
    private _reverse;
    private _onSplice;
    private _onReplace;
    private _onMove;
    private _onClear;
    private _onReorder;
}
export default ArrayReverser;
declare namespace ArrayReverser {
    /**
     * Configuration of `ArrayReverser`.
     */
    interface Config<T> {
        /**
         * Target array. By default, created automatically.
         */
        readonly target?: IBindableArray<T>;
    }
}
/**
 * Creates a new array bound to another array with `ArrayReverser`.
 * @param source Source array.
 * @returns Reversed array.
 */
export declare function startReversingArray<T>(source: ReadonlyBindableArray<T>): DestroyableReadonlyBindableArray<T>;
