import Class from "../Class";
import DestroyableReadonlyBindableMap from '../DestroyableReadonlyBindableMap';
import IBindableMap from '../IBindableMap';
import ReadonlyBindableMap from '../ReadonlyBindableMap';
/**
 * Binds one map to another, filling it with entries of the source map a function returns a truthy value for.
 */
declare class MapFilterer<K, V> extends Class {
    readonly source: ReadonlyBindableMap<K, V>;
    private test;
    private _target;
    private _targetCreated;
    private controlledKeys;
    /**
     * @param source Source map.
     * @param test Filtering criteria.
     * @param config Filterer configuration.
     */
    constructor(source: ReadonlyBindableMap<K, V>, test: (value: V) => boolean, config?: MapFilterer.Config<K, V>);
    /**
     * Target map.
     */
    get target(): ReadonlyBindableMap<K, V>;
    protected destroyObject(): void;
    private _onSplice;
    private _onReindex;
    private _onClear;
    private _prepareToSet;
    private _prepareToRemove;
}
export default MapFilterer;
declare namespace MapFilterer {
    /**
     * Configuration of `MapFilterer`.
     */
    interface Config<K, V> {
        /**
         * Target map.
         */
        readonly target?: IBindableMap<K, V>;
    }
}
/**
 * Creates a new map bound to another map with `MapFilterer`.
 * @param source Source map.
 * @param test Filtering criteria.
 * @returns Target map.
 */
export declare function startFilteringMap<K, V>(source: ReadonlyBindableMap<K, V>, test: (value: V) => boolean): DestroyableReadonlyBindableMap<K, V>;
