import Class from '../Class';
import ReadonlyBindableMap from '../ReadonlyBindableMap';
/**
 * Handles all messages of %ReadonlyBindableMap with a combination of three callbacks.
 */
declare class MapInserter<K, V> extends Class {
    readonly source: ReadonlyBindableMap<K, V>;
    protected _add: (value: V, key: K) => void;
    protected _remove: (value: V, key: K) => void;
    protected _clear: (entries: ReadonlyMap<K, V>) => void;
    /**
     * @param source Source map.
     * @param config Inserter configuration.
     */
    constructor(source: ReadonlyBindableMap<K, V>, config?: MapInserter.Config<K, V>);
    protected destroyObject(): void;
    private _addEntries;
    private _removeEntries;
    private _doClearItems;
    private _onSplice;
    private _onReindex;
    private _onClear;
}
export default MapInserter;
declare namespace MapInserter {
    /**
     * Configuration of `MapInserter`.
     */
    interface Config<K, V> {
        /**
         * Callback to call when an entry is added or updated in the map.
         */
        readonly add?: (value: V, key: K) => void;
        /**
         * Callback to call when an entry is removed or updated in the map.
         */
        readonly remove?: (value: V, key: K) => void;
        /**
         * Callback to call when the map is cleared. By default, calls `remove` for all map entries.
         */
        readonly clear?: (entries: ReadonlyMap<K, V>) => void;
    }
}
