import DestroyableReadonlyBindableMap from '../DestroyableReadonlyBindableMap';
import IBindableMap from '../IBindableMap';
import ReadonlyBindableMap from '../ReadonlyBindableMap';
import AbstractMapper from './AbstractMapper';
/**
 * `AbstractMapper` implementation for map values.
 */
declare class MapMapper<K, T, U> extends AbstractMapper<T, U> {
    readonly source: ReadonlyBindableMap<K, T>;
    private _target;
    private _targetCreated;
    /**
     * @param source Source map.
     * @param create Mapping callback.
     * @param config Mapper configuration.
     */
    constructor(source: ReadonlyBindableMap<K, T>, create: (data: T) => U, config?: MapMapper.FullConfig<K, T, U>);
    /**
     * Target map.
     */
    get target(): ReadonlyBindableMap<K, U>;
    protected destroyObject(): void;
    private _destroyItems;
    private _onSplice;
    private _onReindex;
    private _onClear;
}
export default MapMapper;
declare namespace MapMapper {
    /**
     * Configuration of `MapMapper`.
     */
    interface FullConfig<K, T, U> extends AbstractMapper.Config<T, U> {
        /**
         * Target map.
         */
        readonly target?: IBindableMap<K, U>;
    }
}
/**
 * Creates a new map bound to another map with `MapMapper`.
 * @param source Source map.
 * @param create Mapping callback.
 * @param config Mapper configuration.
 * @returns Target map.
 */
export declare function startMappingMap<K, T, U>(source: ReadonlyBindableMap<K, T>, create: (sourceValue: T) => U, config?: AbstractMapper.Config<T, U>): DestroyableReadonlyBindableMap<K, U>;
