import Class from "../Class";
import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from "../IBindableArray";
import ReadonlyBindableArray from "../ReadonlyBindableArray";
import ReadonlyBindableSet from '../ReadonlyBindableSet';
/**
 * Binds an array to a set, filling it with values of the set in natural order. This order may differ in different
 * browsers. After initialization, all newly added values get appended to the end of the array.
 */
export default class SetConverterToArray<T> extends Class {
    readonly source: ReadonlyBindableSet<T>;
    private _targetCreated;
    private _target;
    /**
     * @param source Source set.
     * @param config Converter configuration.
     */
    constructor(source: ReadonlyBindableSet<T>, config?: SetConverterToArray.Config<T>);
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<T>;
    protected destroyObject(): void;
    private _onSplice;
    private _onClear;
    protected _splice(removedValueSet: ReadonlySet<T>, addedValueSet: ReadonlySet<T>): void;
}
declare namespace SetConverterToArray {
    /**
     * Configuration of `SetConverterToArray`.
     */
    interface Config<T> {
        /**
         * Target array. By default, created automatically.
         */
        readonly target?: IBindableArray<T>;
    }
}
/**
 * Creates a new array bound to a set with `SetConverterToArray`.
 * @param source Source set.
 * @returns Target array.
 */
export declare function startConvertingSetToArray<T>(source: ReadonlyBindableSet<T>): DestroyableReadonlyBindableArray<T>;
export {};
