import Class from "../Class";
import DestroyableReadonlyBindableSet from '../DestroyableReadonlyBindableSet';
import IBindableSet from '../IBindableSet';
import ReadonlyBindableSet from '../ReadonlyBindableSet';
/**
 * Binds one set to another, filling it with values of the source set a callback function returns a truthy value for.
 */
declare class SetFilterer<T> extends Class {
    readonly source: ReadonlyBindableSet<T>;
    private test;
    private _target;
    private _targetCreated;
    /**
     * @param source Source set.
     * @param test Filtering criteria.
     * @param config Filterer configuration.
     */
    constructor(source: ReadonlyBindableSet<T>, test: (value: T) => boolean, config?: SetFilterer.Config<T>);
    /**
     * Target set.
     */
    get target(): ReadonlyBindableSet<T>;
    protected destroyObject(): void;
    private _onSplice;
    private _onClear;
}
export default SetFilterer;
declare namespace SetFilterer {
    /**
     * Configuration of `SetFilterer`.
     */
    interface Config<T> {
        /**
         * Target set.
         */
        readonly target?: IBindableSet<T>;
    }
}
/**
 * Creates a new set bound to another set with `SetFilterer`.
 * @param source Source set.
 * @param test Filtering criteria.
 * @returns Target set.
 */
export declare function startFilteringSet<T>(source: ReadonlyBindableSet<T>, test: (value: T) => boolean): DestroyableReadonlyBindableSet<T>;
