import Class from "../Class";
import DestroyableReadonlyBindableMap from '../DestroyableReadonlyBindableMap';
import IBindableMap from "../IBindableMap";
import ReadonlyBindableMap from "../ReadonlyBindableMap";
import ReadonlyBindableSet from '../ReadonlyBindableSet';
/**
 * Binds a map to a set, giving each value a key equal to the result of a function call for it.
 */
export default class SetIndexer<V, K> extends Class {
    readonly source: ReadonlyBindableSet<V>;
    private getKey;
    private _targetCreated;
    private _target;
    /**
     * @param source Source set.
     * @param getKey Indexer function.
     * @param config Indexer configuration.
     */
    constructor(source: ReadonlyBindableSet<V>, getKey: (value: V) => K, config?: SetIndexer.Config<V, K>);
    /**
     * Target map.
     */
    get target(): ReadonlyBindableMap<K, V>;
    protected destroyObject(): void;
    private _onSplice;
    private _onClear;
}
declare namespace SetIndexer {
    /**
     * Configuration of `SetIndexer`.
     */
    interface Config<V, K> {
        /**
         * Target map. By default, created automatically.
         */
        readonly target?: IBindableMap<K, V>;
    }
}
/**
 * Creates a new map bound to a set with `SetIndexer`.
 * @param source Source set.
 * @param getKey Indexer function.
 * @returns Set index map.
 */
export declare function startIndexingSet<V, K>(source: ReadonlyBindableSet<V>, getKey: (value: V) => K): DestroyableReadonlyBindableMap<K, V>;
export {};
