import DestroyableReadonlyBindableSet from '../DestroyableReadonlyBindableSet';
import IBindableSet from '../IBindableSet';
import ReadonlyBindableSet from '../ReadonlyBindableSet';
import AbstractMapper from './AbstractMapper';
/**
 * `AbstractMapper` implementation for sets.
 */
declare class SetMapper<T, U> extends AbstractMapper<T, U> {
    readonly source: ReadonlyBindableSet<T>;
    private _target;
    private _targetCreated;
    private readonly _items;
    /**
     * @param source Source set.
     * @param create Mapping callback.
     * @param config Mapper configuration.
     */
    constructor(source: ReadonlyBindableSet<T>, create: (data: T) => U, config?: SetMapper.FullConfig<T, U>);
    /**
     * Target set.
     */
    get target(): ReadonlyBindableSet<U>;
    protected destroyObject(): void;
    private _getItems;
    private _createItems;
    private _destroyItems;
    private _onSplice;
    private _onClear;
}
export default SetMapper;
declare namespace SetMapper {
    /**
     * Configuration of `SetMapper`.
     */
    interface FullConfig<T, U> extends AbstractMapper.Config<T, U> {
        /**
         * Target set.
         */
        readonly target?: IBindableSet<U>;
    }
}
/**
 * Creates a new set bound to another set with `SetMapper`.
 * @param source Source set.
 * @param create Mapping callback.
 * @param config Mapper configuration.
 * @returns Target set.
 */
export declare function startMappingSet<T, U>(source: ReadonlyBindableSet<T>, create: (sourceValue: T) => U, config?: AbstractMapper.Config<T, U>): DestroyableReadonlyBindableSet<U>;
