import Bindable from "../Bindable";
import Class from "../Class";
import DestroyableBindable from '../DestroyableBindable';
import IProperty from "../IProperty";
import ReadonlyBindableSet from '../ReadonlyBindableSet';
/**
 * Binds a `Property` to a set, assigning it to the number of values a function returns a truthy value for.
 */
export default class SetMatchingValueCounter<T> extends Class {
    readonly source: ReadonlyBindableSet<T>;
    private test;
    private _targetCreated;
    private _target;
    private _matchingFromThisSource;
    /**
     * @param source Source set.
     * @param test Criteria.
     * @param config Counter configuration.
     */
    constructor(source: ReadonlyBindableSet<T>, test: (value: T) => boolean, config?: SetMatchingValueCounter.Config);
    /**
     * Target property.
     */
    get target(): Bindable<number>;
    protected destroyObject(): void;
    /**
     * Changes counter configuration and recounts matching values.
     * @param config Options to modify.
     */
    reconfigure(config: SetMatchingValueCounter.Reconfig<T>): void;
    /**
     * Recounts matching values. Call this method when set value properties change in such a way that
     * they must be retested.
     */
    recount(): void;
    private _onSplice;
    private _onClear;
}
declare namespace SetMatchingValueCounter {
    /**
     * Configuration of `SetMatchingValueCounter`.
     */
    interface Config {
        /**
         * Target property. By default, created automatically.
         */
        readonly target?: IProperty<number>;
    }
    /**
     * Configuration of `SetMatchingValueCounter.reconfigure` method.
     */
    interface Reconfig<T> {
        /**
         * Criteria.
         */
        readonly test?: (value: T) => boolean;
    }
}
/**
 * Creates a new property bound to a set with `SetMatchingValueCounter`.
 * @param source Source set.
 * @param test Criteria.
 * @returns Target property.
 */
export declare function startCountingMatchingSetValues<T>(source: ReadonlyBindableSet<T>, test: (value: T) => boolean): DestroyableBindable<number>;
export {};
