import Class from "../Class";
import DestroyableReadonlyBindableArray from '../DestroyableReadonlyBindableArray';
import IBindableArray from "../IBindableArray";
import ReadonlyBindableArray from "../ReadonlyBindableArray";
import ReadonlyBindableSet from '../ReadonlyBindableSet';
/**
 * Binds an array to a set, filling it with sorted values of the set.
 */
export default class SetSorter<T> extends Class {
    readonly source: ReadonlyBindableSet<T>;
    private _compare;
    private _order;
    private _targetCreated;
    private _target;
    /**
     * @param source Source set.
     * @param config Sorter configuration.
     */
    constructor(source: ReadonlyBindableSet<T>, config?: SetSorter.FullConfig<T>);
    /**
     * Target array.
     */
    get target(): ReadonlyBindableArray<T>;
    /**
     * Resorts target array forcibly. Call this method on modification of sorting factors.
     */
    resort(): void;
    protected destroyObject(): void;
    private _onSplice;
    private _onClear;
    private _splice;
}
declare namespace SetSorter {
    /**
     * Configuration of `startSortingSet` and partial configuration of `SetSorter`.
     */
    interface Config<T> {
        /**
         * Value comparing callback. Defaults to `cmp`.
         */
        readonly compare?: (x: T, y: T) => number;
        /**
         * Sorting order. Positive number for ascending sorting, negative for descending sorting. Defaults to 1.
         */
        readonly order?: number;
    }
    /**
     * Full configuration of `SetSorter`.
     */
    interface FullConfig<T> extends Config<T> {
        /**
         * Target array. By default, created automatically.
         */
        readonly target?: IBindableArray<T>;
    }
}
/**
 * Creates a new array bound to a set with `SetSorter`.
 * @param source Source set.
 * @param config Sorter configuration.
 * @returns Sorted list.
 */
export declare function startSortingSet<T>(source: ReadonlyBindableSet<T>, config?: SetSorter.Config<T>): DestroyableReadonlyBindableArray<T>;
export {};
