import IProperty from "./IProperty";
/**
 * Interface of `hash` object. Extension of IProperty<string> interface with `updating` status indicator and
 * `replaceState` optional parameter of `set` method.
 */
export interface IHash extends IProperty<string> {
    /**
     * Indicates if hash assignment is in progress at the moment. While `updating` is true, `location.hash`
     * gets modified and a change message gets dispatched. Checking this flag in corresponding event handlers may prevent
     * infinite loops and unexpected callback conflicts.
     */
    readonly updating: boolean;
    /**
     * Assigns `location.hash` to a new value and dispatches a change message. Raises `updating` flag to prevent
     * infinite loops and callback conflicts during this time.
     * @param value New hash value to assign.
     * @param replaceState Replace the current browser historical state rather than pushing a new state to the stack.
     */
    set(value: string, replaceState?: boolean): void;
}
/**
 * Instance of IHash singleton. Provides a transparent Property-compatible interface over `location.hash`
 * manipulations. Value of this property is always equal to `location.hash` without leading "#" symbol.
 * Has a built-in protection against infinite redirections.
 */
declare let hash: IHash;
export default hash;
